package cn.com.qmth.examcloud.core.basic.dao.entity;

import javax.persistence.Entity;
import javax.persistence.EnumType;
import javax.persistence.Enumerated;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import cn.com.qmth.examcloud.commons.base.util.excel.ExcelProperty;
import cn.com.qmth.examcloud.commons.web.jpa.JpaEntity;
import cn.com.qmth.examcloud.core.basic.dao.enums.OrgType;

/**
 * Created by songyue on 17/1/13.
 */
@Entity
@Table(name = "ecs_core_org")
public class Org extends JpaEntity {

	private static final long serialVersionUID = -592353272256492483L;

	@Id
	@GeneratedValue
	private Long id;

	/**
	 * 顶级机构ID,顶级机构的顶级ID为其自身ID
	 */
	@NotNull
	private Long rootId;

	/**
	 * 父级机构ID,无上级时为null; eg.学习中心的父级为学校
	 */
	private Long parentId;

	private Integer level;

	@ExcelProperty(name = "机构名称", index = 0)
	@NotNull
	private String name;

	/**
	 * 学习中心代码
	 */
	@ExcelProperty(name = "机构代码", index = 1)
	@NotNull
	private String code;

	private String logo;

	private String address;

	/**
	 * 可使用的应用模块
	 */
	private String apps;

	@NotNull
	private Boolean enable;

	/**
	 * 联系电话
	 */
	@ExcelProperty(name = "联系电话", index = 3)
	private String telphone;

	/**
	 * 联系人
	 */
	@ExcelProperty(name = "联系人", index = 2)
	private String contacts;

	/**
	 * 机构类型：学校，启明，印刷
	 */
	@Enumerated(EnumType.STRING)
	private OrgType type;

	/**
	 * 机器数量
	 */
	private Integer macNumber;

	/**
	 * 是否提供人员
	 */
	private Boolean isProvide;

	/**
	 * 备注
	 */
	private String remark;

	/**
	 * 网考端系统名称
	 */
	private String examSysName;

	public static long getSerialVersionUID() {
		return serialVersionUID;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getRootId() {
		return rootId;
	}

	public void setRootId(Long rootId) {
		this.rootId = rootId;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public Integer getLevel() {
		return level;
	}

	public void setLevel(Integer level) {
		this.level = level;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getLogo() {
		return logo;
	}

	public void setLogo(String logo) {
		this.logo = logo;
	}

	public String getAddress() {
		return address;
	}

	public void setAddress(String address) {
		this.address = address;
	}

	public String getApps() {
		return apps;
	}

	public void setApps(String apps) {
		this.apps = apps;
	}

	public Boolean getEnable() {
		return enable;
	}

	public void setEnable(Boolean enable) {
		this.enable = enable;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getTelphone() {
		return telphone;
	}

	public void setTelphone(String telphone) {
		this.telphone = telphone;
	}

	public String getContacts() {
		return contacts;
	}

	public void setContacts(String contacts) {
		this.contacts = contacts;
	}

	public OrgType getType() {
		return type;
	}

	public void setType(OrgType type) {
		this.type = type;
	}

	public Integer getMacNumber() {
		return macNumber;
	}

	public void setMacNumber(Integer macNumber) {
		this.macNumber = macNumber;
	}

	public Boolean getIsProvide() {
		return isProvide;
	}

	public void setIsProvide(Boolean isProvide) {
		this.isProvide = isProvide;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getExamSysName() {
		return examSysName;
	}

	public void setExamSysName(String examSysName) {
		this.examSysName = examSysName;
	}

	public Org(String name, String code, String contacts, String telphone) {
		this.name = name;
		this.code = code;
		this.telphone = telphone;
		this.contacts = contacts;
	}

	public Org() {
	}
}
